package com.example.mainapplicathiongeorge31p.screens

import android.annotation.SuppressLint
import android.content.res.Configuration
import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.material3.TextFieldDefaults
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color

import androidx.compose.ui.platform.LocalConfiguration
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavHostController
import kotlinx.coroutines.delay


@OptIn(ExperimentalMaterial3Api::class)
@SuppressLint("RememberReturnType")

@Composable
fun StartScreen(navController: NavHostController) {
    val email = remember { mutableStateOf("") }
    Column(
        modifier = Modifier
            .background(Color(0xfffffff))
            .fillMaxSize(),
        verticalArrangement = Arrangement.SpaceAround
    ) {
        Column () {
            Column() {
                Text(
                    text = "✋  Добро пожаловать!",
                    fontSize = 24.sp,
                    modifier = Modifier.padding(20.dp, 0.dp, 0.dp, 30.dp),
                    fontWeight = FontWeight.Bold
                )
                Text(
                    text = "Войдите, чтобы пользоваться функциями приложения",
                    fontSize = 15.sp,
                    modifier = Modifier.padding(start = 20.dp)
                )
            }
            Column(modifier = Modifier.padding(top = 50.dp)) {
                Text(
                    text = "Вход по E-mail",
                    fontSize = 14.sp,
                    modifier = Modifier.padding(20.dp, 30.dp, 0.dp, 5.dp),
                    color = Color.Gray
                )

                TextField(
                    value = email.value,
                    onValueChange = { newText -> email.value = newText },
                    modifier = Modifier
                        .padding(20.dp, 0.dp, 20.dp, 0.dp)
                        .fillMaxWidth(1f),
                    maxLines = 1,
                    singleLine = true,
                    shape = RoundedCornerShape(13.dp),
                    colors = TextFieldDefaults.textFieldColors(
                        containerColor = Color(0xFFF5F5F9),
                        focusedIndicatorColor = Color.Transparent,
                        unfocusedIndicatorColor = Color.Transparent,
                        cursorColor = Color.Black,
                        unfocusedPlaceholderColor = Color.Gray,
                        disabledTextColor = Color.Transparent,
                        disabledIndicatorColor = Color.Transparent
                    ),

                    placeholder = { Text("example@mail.ru") }

                )

                Button(
                    onClick = {navController.navigate("CodeInEmail")},
                    enabled = email.value.isNotEmpty(),
                    shape = RoundedCornerShape(15.dp),
                    colors = ButtonDefaults.buttonColors(
                        disabledContainerColor = Color(0xFFC9D4FB),
                        containerColor = Color(0xFF1A6FEE)),
                    modifier = Modifier
                        .padding(top = 30.dp, start = 20.dp, end = 20.dp)
                        .height(55.dp)
                        .fillMaxWidth(1f)
                ) {
                    Text(text = "Далее", fontSize = 20.sp, color = Color(0xFFffffff))
                }

            }
        }
        Column(modifier = Modifier.padding(top = 170.dp)) {
            Text(
                text = "Или войдите с помощью",
                fontSize = 15.sp,
                color = Color(0xFF939396),
                textAlign = TextAlign.Center,
                modifier = Modifier.fillMaxWidth()
            )

            Button(
                onClick = {},
                modifier = Modifier
                    .padding(top = 15.dp, start = 20.dp, end = 20.dp)
                    .fillMaxWidth(1f)
                    .height(60.dp),
                shape = RoundedCornerShape(15.dp),
                colors = ButtonDefaults.buttonColors(containerColor = Color(0xFFffffff)),
                border = BorderStroke(
                    1.dp, color = Color(0xFFEBEBEB)
                )
            ) {
                Text(
                    text = "Войти с Яндекс", fontSize = 20.sp,
                    color = Color(0xFF000000),
                    fontWeight = FontWeight.Bold
                )
            }
        }
    }
}

